pub struct ProposalCreationResponse {
pub proposal_id: u64,
}Fields
proposal_id: u64Trait Implementations
Sourceimpl Clone for ProposalCreationResponse
impl Clone for ProposalCreationResponse
Sourcefn clone(&self) -> ProposalCreationResponse
fn clone(&self) -> ProposalCreationResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProposalCreationResponse
impl Debug for ProposalCreationResponse
Sourceimpl<'de> Deserialize<'de> for ProposalCreationResponse
impl<'de> Deserialize<'de> for ProposalCreationResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProposalCreationResponse
Sourceimpl JsonSchema for ProposalCreationResponse
impl JsonSchema for ProposalCreationResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProposalCreationResponse
impl PartialEq for ProposalCreationResponse
Sourceimpl Serialize for ProposalCreationResponse
impl Serialize for ProposalCreationResponse
impl StructuralPartialEq for ProposalCreationResponse