pub struct ProposalListResponse<P> {
pub proposals: Vec<ProposalResponse<P>>,
}Fields
proposals: Vec<ProposalResponse<P>>Trait Implementations
Sourceimpl<P: Clone> Clone for ProposalListResponse<P>
impl<P: Clone> Clone for ProposalListResponse<P>
Sourcefn clone(&self) -> ProposalListResponse<P>
fn clone(&self) -> ProposalListResponse<P>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<P: Debug> Debug for ProposalListResponse<P>
impl<P: Debug> Debug for ProposalListResponse<P>
Sourceimpl<'de, P> Deserialize<'de> for ProposalListResponse<P>where
P: Deserialize<'de>,
impl<'de, P> Deserialize<'de> for ProposalListResponse<P>where
P: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<P: Eq> Eq for ProposalListResponse<P>
Sourceimpl<P: JsonSchema> JsonSchema for ProposalListResponse<P>
impl<P: JsonSchema> JsonSchema for ProposalListResponse<P>
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<P: PartialEq> PartialEq for ProposalListResponse<P>
impl<P: PartialEq> PartialEq for ProposalListResponse<P>
Sourceimpl<P> Serialize for ProposalListResponse<P>where
P: Serialize,
impl<P> Serialize for ProposalListResponse<P>where
P: Serialize,
impl<P: PartialEq> StructuralPartialEq for ProposalListResponse<P>