pub struct ProposalResponse<P> {
pub id: u64,
pub title: String,
pub description: String,
pub created_by: String,
pub proposal: P,
pub status: Status,
pub expires: Expiration,
pub rules: VotingRules,
pub total_points: u64,
pub votes: Votes,
}Expand description
Note, if you are storing custom messages in the proposal, the querier needs to know what possible custom message types those are in order to parse the response
Fields
id: u64title: Stringdescription: Stringcreated_by: Stringproposal: Pstatus: Statusexpires: Expirationrules: VotingRulestotal_points: u64votes: VotesTrait Implementations
Sourceimpl<P: Clone> Clone for ProposalResponse<P>
impl<P: Clone> Clone for ProposalResponse<P>
Sourcefn clone(&self) -> ProposalResponse<P>
fn clone(&self) -> ProposalResponse<P>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<P: Debug> Debug for ProposalResponse<P>
impl<P: Debug> Debug for ProposalResponse<P>
Sourceimpl<'de, P> Deserialize<'de> for ProposalResponse<P>where
P: Deserialize<'de>,
impl<'de, P> Deserialize<'de> for ProposalResponse<P>where
P: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<P: Eq> Eq for ProposalResponse<P>
Sourceimpl<P: JsonSchema> JsonSchema for ProposalResponse<P>
impl<P: JsonSchema> JsonSchema for ProposalResponse<P>
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<P: PartialEq> PartialEq for ProposalResponse<P>
impl<P: PartialEq> PartialEq for ProposalResponse<P>
Sourceimpl<P> Serialize for ProposalResponse<P>where
P: Serialize,
impl<P> Serialize for ProposalResponse<P>where
P: Serialize,
impl<P: PartialEq> StructuralPartialEq for ProposalResponse<P>