pub struct TextProposalListResponse {
pub proposals: Vec<ProposalInfo>,
}Fields
proposals: Vec<ProposalInfo>Trait Implementations
Sourceimpl Clone for TextProposalListResponse
impl Clone for TextProposalListResponse
Sourcefn clone(&self) -> TextProposalListResponse
fn clone(&self) -> TextProposalListResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TextProposalListResponse
impl Debug for TextProposalListResponse
Sourceimpl<'de> Deserialize<'de> for TextProposalListResponse
impl<'de> Deserialize<'de> for TextProposalListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TextProposalListResponse
Sourceimpl JsonSchema for TextProposalListResponse
impl JsonSchema for TextProposalListResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TextProposalListResponse
impl PartialEq for TextProposalListResponse
Sourceimpl Serialize for TextProposalListResponse
impl Serialize for TextProposalListResponse
impl StructuralPartialEq for TextProposalListResponse